<?php

/**
 * @file
 * Definition of views_handler_filter_community_tasks_state.
 */

/**
 * Filter community tasks state.
 *
 * @ingroup views_filter_handlers
 */
class views_handler_filter_community_tasks_state extends views_handler_filter_in_operator {

  /**
   * Query expressions.
   */
  function query() {
    $table   = $this->ensure_my_table();
    $promote = NODE_PROMOTED;

    if ($this->value) {
      foreach ($this->value as $value) {
        switch ($value) {
          case 'open':
            $this->query->add_where_expression($this->options['group'], "$table.uid = 1");
            break;
          case 'completed':
            $this->query->add_where_expression($this->options['group'], "$table.promote = $promote");
            break;
          case 'committed':
            $this->query->add_where_expression($this->options['group'], "$table.promote != $promote AND $table.uid != 1");
            break;
        }
      }
    }
  }


  /**
   * Disable multiple chosen in admin form.
   *
   * @param $form
   * @param $form_state
   */
  function expose_form(&$form, &$form_state) {
    parent::expose_form($form, $form_state);

    if (isset($form['expose']['multiple'])) {
      unset($form['expose']['multiple']);
    }
  }


  /**
   * Set available states options.
   */
  function get_value_options() {
    if (!isset($this->value_options)) {
      $this->value_title = t('Community Tasks state');

      $options = array();
      foreach ($this->get_community_tasks_states() as $state) {
        $options[$state] = ct_state_names($state);
      }

      $this->value_options = $options;
    }
  }


  /**
   * Get available community tasks states.
   *
   * @return array
   */
  private function get_community_tasks_states() {
    return array(
      'open',
      'completed',
      'committed',
    );
  }
}
